Package: MatrixGenerics
Title: S4 Generic Summary Statistic Functions that Operate on
        Matrix-Like Objects
Description: S4 generic functions modeled after the 'matrixStats' API
        for alternative matrix implementations. Packages with
        alternative matrix implementation can depend on this package
        and implement the generic functions that are defined here for a
        useful set of row and column summary statistics. Other package
        developers can import this package and handle a different
        matrix implementations without worrying about
        incompatibilities.
biocViews: Infrastructure, Software
URL: https://bioconductor.org/packages/MatrixGenerics
BugReports: https://github.com/Bioconductor/MatrixGenerics/issues
Version: 1.25.0
License: Artistic-2.0
Encoding: UTF-8
Authors@R: c(person("Constantin", "Ahlmann-Eltze",
                email = "artjom31415@googlemail.com", role = c("aut"),
                comment = c(ORCID = "0000-0002-3762-068X")),
            person("Peter", "Hickey", role = c("aut", "cre"),
                email = "peter.hickey@gmail.com",
                comment = c(ORCID = "0000-0002-8153-6258")),
            person("Hervé", "Pagès", email = "hpages.on.github@gmail.com",
                role = "aut"))
Depends: matrixStats (>= 1.4.1)
Imports: methods
Suggests: Matrix, sparseMatrixStats, SparseArray, DelayedArray,
        DelayedMatrixStats, SummarizedExperiment, testthat (>= 2.1.0)
RoxygenNote: 7.3.2
Roxygen: list(markdown = TRUE, old_usage = TRUE)
Collate: 'MatrixGenerics-package.R' 'rowAlls.R' 'rowAnyNAs.R'
        'rowAnys.R' 'rowAvgsPerColSet.R' 'rowCollapse.R' 'rowCounts.R'
        'rowCummaxs.R' 'rowCummins.R' 'rowCumprods.R' 'rowCumsums.R'
        'rowDiffs.R' 'rowIQRDiffs.R' 'rowIQRs.R' 'rowLogSumExps.R'
        'rowMadDiffs.R' 'rowMads.R' 'rowMaxs.R' 'rowMeans.R'
        'rowMeans2.R' 'rowMedians.R' 'rowMins.R' 'rowOrderStats.R'
        'rowProds.R' 'rowQuantiles.R' 'rowRanges.R' 'rowRanks.R'
        'rowSdDiffs.R' 'rowSds.R' 'rowSums.R' 'rowSums2.R'
        'rowTabulates.R' 'rowVarDiffs.R' 'rowVars.R'
        'rowWeightedMads.R' 'rowWeightedMeans.R' 'rowWeightedMedians.R'
        'rowWeightedSds.R' 'rowWeightedVars.R'
Repository: https://bioc.r-universe.dev
Date/Publication: 2026-04-28 12:52:18 UTC
RemoteUrl: https://github.com/bioc/MatrixGenerics
RemoteRef: HEAD
RemoteSha: 84fb7a5ce4bb795ef791b79011db25ee80a336e6
NeedsCompilation: no
Packaged: 2026-05-30 07:40:32 UTC; root
Author: Constantin Ahlmann-Eltze [aut] (ORCID:
    <https://orcid.org/0000-0002-3762-068X>),
  Peter Hickey [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-8153-6258>),
  Hervé Pagès [aut]
Maintainer: Peter Hickey <peter.hickey@gmail.com>
Built: R 4.6.0; ; 2026-05-30 10:55:51 UTC; unix
