# Generated by roxygen2: do not edit by hand

export(colAlls)
export(colAnyNAs)
export(colAnys)
export(colAvgsPerRowSet)
export(colCollapse)
export(colCounts)
export(colCummaxs)
export(colCummins)
export(colCumprods)
export(colCumsums)
export(colDiffs)
export(colIQRDiffs)
export(colIQRs)
export(colLogSumExps)
export(colMadDiffs)
export(colMads)
export(colMaxs)
export(colMeans)
export(colMeans2)
export(colMedians)
export(colMins)
export(colOrderStats)
export(colProds)
export(colQuantiles)
export(colRanges)
export(colRanks)
export(colSdDiffs)
export(colSds)
export(colSums)
export(colSums2)
export(colTabulates)
export(colVarDiffs)
export(colVars)
export(colWeightedMads)
export(colWeightedMeans)
export(colWeightedMedians)
export(colWeightedSds)
export(colWeightedVars)
export(normarg_center)
export(rowAlls)
export(rowAnyNAs)
export(rowAnys)
export(rowAvgsPerColSet)
export(rowCollapse)
export(rowCounts)
export(rowCummaxs)
export(rowCummins)
export(rowCumprods)
export(rowCumsums)
export(rowDiffs)
export(rowIQRDiffs)
export(rowIQRs)
export(rowLogSumExps)
export(rowMadDiffs)
export(rowMads)
export(rowMaxs)
export(rowMeans)
export(rowMeans2)
export(rowMedians)
export(rowMins)
export(rowOrderStats)
export(rowProds)
export(rowQuantiles)
export(rowRanges)
export(rowRanks)
export(rowSdDiffs)
export(rowSds)
export(rowSums)
export(rowSums2)
export(rowTabulates)
export(rowVarDiffs)
export(rowVars)
export(rowWeightedMads)
export(rowWeightedMeans)
export(rowWeightedMedians)
export(rowWeightedSds)
export(rowWeightedVars)
exportClasses(matrix_OR_array_OR_table_OR_numeric)
exportMethods(colAlls)
exportMethods(colAnyNAs)
exportMethods(colAnys)
exportMethods(colAvgsPerRowSet)
exportMethods(colCollapse)
exportMethods(colCounts)
exportMethods(colCummaxs)
exportMethods(colCummins)
exportMethods(colCumprods)
exportMethods(colCumsums)
exportMethods(colDiffs)
exportMethods(colIQRDiffs)
exportMethods(colIQRs)
exportMethods(colLogSumExps)
exportMethods(colMadDiffs)
exportMethods(colMads)
exportMethods(colMaxs)
exportMethods(colMeans2)
exportMethods(colMedians)
exportMethods(colMins)
exportMethods(colOrderStats)
exportMethods(colProds)
exportMethods(colQuantiles)
exportMethods(colRanges)
exportMethods(colRanks)
exportMethods(colSdDiffs)
exportMethods(colSds)
exportMethods(colSums2)
exportMethods(colTabulates)
exportMethods(colVarDiffs)
exportMethods(colVars)
exportMethods(colWeightedMads)
exportMethods(colWeightedMeans)
exportMethods(colWeightedMedians)
exportMethods(colWeightedSds)
exportMethods(colWeightedVars)
exportMethods(rowAlls)
exportMethods(rowAnyNAs)
exportMethods(rowAnys)
exportMethods(rowAvgsPerColSet)
exportMethods(rowCollapse)
exportMethods(rowCounts)
exportMethods(rowCummaxs)
exportMethods(rowCummins)
exportMethods(rowCumprods)
exportMethods(rowCumsums)
exportMethods(rowDiffs)
exportMethods(rowIQRDiffs)
exportMethods(rowIQRs)
exportMethods(rowLogSumExps)
exportMethods(rowMadDiffs)
exportMethods(rowMads)
exportMethods(rowMaxs)
exportMethods(rowMeans2)
exportMethods(rowMedians)
exportMethods(rowMins)
exportMethods(rowOrderStats)
exportMethods(rowProds)
exportMethods(rowQuantiles)
exportMethods(rowRanges)
exportMethods(rowRanks)
exportMethods(rowSdDiffs)
exportMethods(rowSds)
exportMethods(rowSums2)
exportMethods(rowTabulates)
exportMethods(rowVarDiffs)
exportMethods(rowVars)
exportMethods(rowWeightedMads)
exportMethods(rowWeightedMeans)
exportMethods(rowWeightedMedians)
exportMethods(rowWeightedSds)
exportMethods(rowWeightedVars)
import(matrixStats)
import(methods)
