% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rowCumsums.R
\name{rowCumsums}
\alias{rowCumsums}
\alias{rowCumsums,matrix_OR_array_OR_table_OR_numeric-method}
\alias{rowCumsums,ANY-method}
\alias{colCumsums}
\alias{colCumsums,matrix_OR_array_OR_table_OR_numeric-method}
\alias{colCumsums,ANY-method}
\title{Calculates the cumulative sum for each row (column) of a matrix-like object}
\usage{
rowCumsums(x, rows = NULL, cols = NULL, ...)

\S4method{rowCumsums}{matrix_OR_array_OR_table_OR_numeric}(x, rows = NULL, cols = NULL, dim. = dim(x), ...)

\S4method{rowCumsums}{ANY}(x, rows = NULL, cols = NULL, ...)

colCumsums(x, rows = NULL, cols = NULL, ...)

\S4method{colCumsums}{matrix_OR_array_OR_table_OR_numeric}(x, rows = NULL, cols = NULL, dim. = dim(x), ...)

\S4method{colCumsums}{ANY}(x, rows = NULL, cols = NULL, ...)
}
\arguments{
\item{x}{An NxK matrix-like object.}

\item{rows, cols}{A \code{\link{vector}} indicating the subset of rows
(and/or columns) to operate over. If \code{\link{NULL}}, no subsetting is
done.}

\item{...}{Additional arguments passed to specific methods.}

\item{dim.}{An \code{\link{integer}} \code{\link{vector}} of length two
specifying the dimension of \code{x}, essential when x is a
\code{\link{numeric}} vector. Note, that this is not a generic
argument and not all methods need provide it.}
}
\value{
Returns a \code{\link{numeric}} \code{\link{matrix}}with the same
dimensions as \code{x}.
}
\description{
Calculates the cumulative sum for each row (column) of a matrix-like object.
}
\details{
The S4 methods for \code{x} of type \code{\link{matrix}},
\code{\link{array}}, or \code{\link{numeric}} call
\code{matrixStats::rowCumsums}
/ \code{matrixStats::colCumsums}.
}
\examples{
  mat <- matrix(rnorm(15), nrow = 5, ncol = 3)
  mat[2, 1] <- NA
  mat[3, 3] <- Inf
  mat[4, 1] <- 0
  
  print(mat)
  
  rowCumsums(mat)
  colCumsums(mat)
  
}
\seealso{
\itemize{
\item \code{matrixStats::\link[matrixStats]{rowCumsums}()} and
\code{matrixStats::\link[matrixStats:rowCumsums]{colCumsums}()} which are
used when the input is a \code{matrix} or \code{numeric} vector.
\item \code{base::\link{cumsum}()}.
}
}
\keyword{array}
\keyword{iteration}
\keyword{robust}
\keyword{univar}
